#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-app-static
version:              3.1.7.2
visibility:           public
id:                   wai-app-static-3.1.7.2-FPi5axGEjv7KYslf5J8doi
key:                  wai-app-static-3.1.7.2-FPi5axGEjv7KYslf5J8doi
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/web-application-interface
synopsis:             WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.

category:             Web, Yesod
abi:                  2efc8731845599b699609f8c4378bbda
exposed:              True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types

hidden-modules:
    Util WaiAppStatic.Storage.Embedded.Runtime
    WaiAppStatic.Storage.Embedded.TH

import-dirs:          /usr/lib/ghc-8.10.2/site-local/wai-app-static-3.1.7.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/wai-app-static-3.1.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.2/wai-app-static-3.1.7.2
hs-libraries:         HSwai-app-static-3.1.7.2-FPi5axGEjv7KYslf5J8doi
depends:
    base-4.14.1.0 blaze-html-0.9.1.2-2CxRFZ3pUcb2942dceW5fY
    blaze-markup-0.8.2.7-LxYHHNtMMqd23FQvjJOkWQ bytestring-0.10.10.0
    containers-0.6.2.1 cryptonite-0.27-HHsLwS0rDVxGOErqbxkj0C
    directory-1.3.6.0 file-embed-0.0.13.0-G4fwjmnadN6Cqq18FbYnBb
    filepath-1.4.2.1 http-date-0.0.10-BIxmKsyVU2l9Xs92kN5nha
    http-types-0.12.3-BjgB5kCegWL53v8V6hA7Kx
    memory-0.15.0-359cYXe7lRF64CAN0G53fp
    mime-types-0.1.0.9-7WG5UcXzH6N6zzQ8X9LvyP
    old-locale-1.0.0.7-LpTuchyagHAP7STZdm71P
    optparse-applicative-0.16.1.0-JDPEASK1GJS1Nsq2qjjZCq
    template-haskell-2.16.0.0 text-1.2.3.2 time-1.9.3
    transformers-0.5.6.2 unix-compat-0.5.2-7IcOHcLTxJI58jp45CNrGP
    unordered-containers-0.2.13.0-HeBOjfSts31GSj9apQxnyX
    wai-3.2.2.1-BYB2v4x1FyK8eqy5kz3dj4
    wai-extra-3.1.5-8ah7ZiDfzSNDuE2iXhkFhW
    warp-3.3.13-5YMIhxHFQMs56eMisupGvu
    zlib-0.6.2.2-85jZF5E8OnCKweDgfCRJUx

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

